# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/image_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-global_vo_grpc_service/protos/image_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xd0\x01\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x05 \x01(\x0b\x32\x08.GeoBbox\x12\x12\n\nfeature_id\x18\x06 \x01(\x05\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x18\x46indOrCreateImageRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"T\n\x19\x46indOrCreateImageResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image\",\n\x13GetImageByIdRequest\x12\x15\n\x05image\x18\x01 \x01(\x0b\x32\x06.Image\"O\n\x14GetImageByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x15\n\x05image\x18\x02 \x01(\x0b\x32\x06.Image2\x93\x01\n\x08ImageApi\x12J\n\x11\x46indOrCreateImage\x12\x19.FindOrCreateImageRequest\x1a\x1a.FindOrCreateImageResponse\x12;\n\x0cGetImageById\x12\x14.GetImageByIdRequest\x1a\x15.GetImageByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.image_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMAGE._serialized_start=126
  _IMAGE._serialized_end=334
  _FINDORCREATEIMAGEREQUEST._serialized_start=336
  _FINDORCREATEIMAGEREQUEST._serialized_end=385
  _FINDORCREATEIMAGERESPONSE._serialized_start=387
  _FINDORCREATEIMAGERESPONSE._serialized_end=471
  _GETIMAGEBYIDREQUEST._serialized_start=473
  _GETIMAGEBYIDREQUEST._serialized_end=517
  _GETIMAGEBYIDRESPONSE._serialized_start=519
  _GETIMAGEBYIDRESPONSE._serialized_end=598
  _IMAGEAPI._serialized_start=601
  _IMAGEAPI._serialized_end=748
# @@protoc_insertion_point(module_scope)
