# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/feature_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/global_vo_grpc_service/protos/feature_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc7\x01\n\x07\x46\x65\x61ture\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0bvendor_name\x18\x02 \x01(\t\x12\x11\n\tvendor_id\x18\x03 \x01(\t\x12(\n\x07\x66\x65\x61ture\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"+\n\x0e\x46\x65\x61tureRequest\x12\x19\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x08.Feature\"N\n\x0f\x46\x65\x61tureResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07\x66\x65\x61ture\x18\x02 \x01(\x0b\x32\x08.Feature\"3\n\x16\x46indFeatureByIdRequest\x12\x19\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32\x08.Feature\"V\n\x17\x46indFeatureByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07\x66\x65\x61ture\x18\x02 \x01(\x0b\x32\x08.Feature2\x8c\x01\n\nFeatureApi\x12\x38\n\x13\x46indOrCreateFeature\x12\x0f.FeatureRequest\x1a\x10.FeatureResponse\x12\x44\n\x0f\x46indFeatureById\x12\x17.FindFeatureByIdRequest\x1a\x18.FindFeatureByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.feature_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FEATURE._serialized_start=158
  _FEATURE._serialized_end=357
  _FEATUREREQUEST._serialized_start=359
  _FEATUREREQUEST._serialized_end=402
  _FEATURERESPONSE._serialized_start=404
  _FEATURERESPONSE._serialized_end=482
  _FINDFEATUREBYIDREQUEST._serialized_start=484
  _FINDFEATUREBYIDREQUEST._serialized_end=535
  _FINDFEATUREBYIDRESPONSE._serialized_start=537
  _FINDFEATUREBYIDRESPONSE._serialized_end=623
  _FEATUREAPI._serialized_start=626
  _FEATUREAPI._serialized_end=766
# @@protoc_insertion_point(module_scope)
