# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/category_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0global_vo_grpc_service/protos/category_api.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)global_vo_grpc_service/protos/utils.proto\"\xfd\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65num\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12)\n\x08includes\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08\x65xcludes\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0f\x43\x61tegoryRequest\x12\x1b\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32\t.Category\"Q\n\x10\x43\x61tegoryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\t.Category\"Y\n\x16ListCategoriesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\ncategories\x18\x02 \x03(\x0b\x32\t.Category2\x8d\x01\n\x0b\x43\x61tegoryApi\x12;\n\x14\x46indOrCreateCategory\x12\x10.CategoryRequest\x1a\x11.CategoryResponse\x12\x41\n\x0eListCategories\x12\x16.google.protobuf.Empty\x1a\x17.ListCategoriesResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.category_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATEGORY._serialized_start=188
  _CATEGORY._serialized_end=441
  _CATEGORYREQUEST._serialized_start=443
  _CATEGORYREQUEST._serialized_end=489
  _CATEGORYRESPONSE._serialized_start=491
  _CATEGORYRESPONSE._serialized_end=572
  _LISTCATEGORIESRESPONSE._serialized_start=574
  _LISTCATEGORIESRESPONSE._serialized_end=663
  _CATEGORYAPI._serialized_start=666
  _CATEGORYAPI._serialized_end=807
# @@protoc_insertion_point(module_scope)
