# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_grpc_service/protos/detection_instance_data_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from global_vo_grpc_service.protos import detection_instance_api_pb2 as global__vo__grpc__service_dot_protos_dot_detection__instance__api__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:data_grpc_service/protos/detection_instance_data_api.proto\x1a:global_vo_grpc_service/protos/detection_instance_api.proto\x1a)global_vo_grpc_service/protos/utils.proto\"?\n+CacheDetectionInstancesDataByImageIdRequest\x12\x10\n\x08image_id\x18\x01 \x01(\x05\"\x81\x01\n,CacheDetectionInstancesDataByImageIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12/\n\x13\x64\x65tection_instances\x18\x02 \x03(\x0b\x32\x12.DetectionInstance\"D\n#GetDetectionInstanceDataByIdRequest\x12\x1d\n\x15\x64\x65tection_instance_id\x18\x01 \x01(\x05\"M\n$GetDetectionInstanceDataByIdResponse\x12%\n\x1d\x64\x65tection_instance_data_bytes\x18\x01 \x01(\x0c\x32\x8f\x02\n\x18\x44\x65tectionInstanceDataApi\x12\x83\x01\n$CacheDetectionInstancesDataByImageId\x12,.CacheDetectionInstancesDataByImageIdRequest\x1a-.CacheDetectionInstancesDataByImageIdResponse\x12m\n\x1cGetDetectionInstanceDataById\x12$.GetDetectionInstanceDataByIdRequest\x1a%.GetDetectionInstanceDataByIdResponse0\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_grpc_service.protos.detection_instance_data_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST._serialized_start=165
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDREQUEST._serialized_end=228
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE._serialized_start=231
  _CACHEDETECTIONINSTANCESDATABYIMAGEIDRESPONSE._serialized_end=360
  _GETDETECTIONINSTANCEDATABYIDREQUEST._serialized_start=362
  _GETDETECTIONINSTANCEDATABYIDREQUEST._serialized_end=430
  _GETDETECTIONINSTANCEDATABYIDRESPONSE._serialized_start=432
  _GETDETECTIONINSTANCEDATABYIDRESPONSE._serialized_end=509
  _DETECTIONINSTANCEDATAAPI._serialized_start=512
  _DETECTIONINSTANCEDATAAPI._serialized_end=783
# @@protoc_insertion_point(module_scope)
