# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: global_vo_grpc_service/protos/workflow_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from global_vo_grpc_service.protos import utils_pb2 as global__vo__grpc__service_dot_protos_dot_utils__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0global_vo_grpc_service/protos/workflow_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a)global_vo_grpc_service/protos/utils.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8e\x02\n\x08Workflow\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\nextra_data\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\".\n\x0fWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Q\n\x10WorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\">\n\x1fTransitionWorkflowStatusRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"a\n TransitionWorkflowStatusResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"6\n\x17QueueMissionScanRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Y\n\x18QueueMissionScanResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"`\n\x1eListQueuedMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"6\n\x17ListMissionScansRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"Z\n\x18ListMissionScansResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"A\n\"ListRelatedMissionScansByIdRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"e\n#ListRelatedMissionScansByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19QueueMissionExportRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"[\n\x1aQueueMissionExportResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow\"b\n ListQueuedMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"8\n\x19ListMissionExportsRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"\\\n\x1aListMissionExportsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1c\n\tworkflows\x18\x02 \x03(\x0b\x32\t.Workflow\"4\n\x15\x44\x65leteWorkflowRequest\x12\x1b\n\x08workflow\x18\x01 \x01(\x0b\x32\t.Workflow\"W\n\x16\x44\x65leteWorkflowResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08workflow\x18\x02 \x01(\x0b\x32\t.Workflow2\xb2\x06\n\x0bWorkflowApi\x12;\n\x14\x46indOrCreateWorkflow\x12\x10.WorkflowRequest\x1a\x11.WorkflowResponse\x12_\n\x18TransitionWorkflowStatus\x12 .TransitionWorkflowStatusRequest\x1a!.TransitionWorkflowStatusResponse\x12\x41\n\x0e\x44\x65leteWorkflow\x12\x16.DeleteWorkflowRequest\x1a\x17.DeleteWorkflowResponse\x12M\n\x12QueueMissionExport\x12\x1a.QueueMissionExportRequest\x1a\x1b.QueueMissionExportResponse\x12U\n\x18ListQueuedMissionExports\x12\x16.google.protobuf.Empty\x1a!.ListQueuedMissionExportsResponse\x12M\n\x12ListMissionExports\x12\x1a.ListMissionExportsRequest\x1a\x1b.ListMissionExportsResponse\x12G\n\x10QueueMissionScan\x12\x18.QueueMissionScanRequest\x1a\x19.QueueMissionScanResponse\x12Q\n\x16ListQueuedMissionScans\x12\x16.google.protobuf.Empty\x1a\x1f.ListQueuedMissionScansResponse\x12G\n\x10ListMissionScans\x12\x18.ListMissionScansRequest\x1a\x19.ListMissionScansResponse\x12h\n\x1bListRelatedMissionScansById\x12#.ListRelatedMissionScansByIdRequest\x1a$.ListRelatedMissionScansByIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'global_vo_grpc_service.protos.workflow_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOW._serialized_start=188
  _WORKFLOW._serialized_end=458
  _WORKFLOWREQUEST._serialized_start=460
  _WORKFLOWREQUEST._serialized_end=506
  _WORKFLOWRESPONSE._serialized_start=508
  _WORKFLOWRESPONSE._serialized_end=589
  _TRANSITIONWORKFLOWSTATUSREQUEST._serialized_start=591
  _TRANSITIONWORKFLOWSTATUSREQUEST._serialized_end=653
  _TRANSITIONWORKFLOWSTATUSRESPONSE._serialized_start=655
  _TRANSITIONWORKFLOWSTATUSRESPONSE._serialized_end=752
  _QUEUEMISSIONSCANREQUEST._serialized_start=754
  _QUEUEMISSIONSCANREQUEST._serialized_end=808
  _QUEUEMISSIONSCANRESPONSE._serialized_start=810
  _QUEUEMISSIONSCANRESPONSE._serialized_end=899
  _LISTQUEUEDMISSIONSCANSRESPONSE._serialized_start=901
  _LISTQUEUEDMISSIONSCANSRESPONSE._serialized_end=997
  _LISTMISSIONSCANSREQUEST._serialized_start=999
  _LISTMISSIONSCANSREQUEST._serialized_end=1053
  _LISTMISSIONSCANSRESPONSE._serialized_start=1055
  _LISTMISSIONSCANSRESPONSE._serialized_end=1145
  _LISTRELATEDMISSIONSCANSBYIDREQUEST._serialized_start=1147
  _LISTRELATEDMISSIONSCANSBYIDREQUEST._serialized_end=1212
  _LISTRELATEDMISSIONSCANSBYIDRESPONSE._serialized_start=1214
  _LISTRELATEDMISSIONSCANSBYIDRESPONSE._serialized_end=1315
  _QUEUEMISSIONEXPORTREQUEST._serialized_start=1317
  _QUEUEMISSIONEXPORTREQUEST._serialized_end=1373
  _QUEUEMISSIONEXPORTRESPONSE._serialized_start=1375
  _QUEUEMISSIONEXPORTRESPONSE._serialized_end=1466
  _LISTQUEUEDMISSIONEXPORTSRESPONSE._serialized_start=1468
  _LISTQUEUEDMISSIONEXPORTSRESPONSE._serialized_end=1566
  _LISTMISSIONEXPORTSREQUEST._serialized_start=1568
  _LISTMISSIONEXPORTSREQUEST._serialized_end=1624
  _LISTMISSIONEXPORTSRESPONSE._serialized_start=1626
  _LISTMISSIONEXPORTSRESPONSE._serialized_end=1718
  _DELETEWORKFLOWREQUEST._serialized_start=1720
  _DELETEWORKFLOWREQUEST._serialized_end=1772
  _DELETEWORKFLOWRESPONSE._serialized_start=1774
  _DELETEWORKFLOWRESPONSE._serialized_end=1861
  _WORKFLOWAPI._serialized_start=1864
  _WORKFLOWAPI._serialized_end=2682
# @@protoc_insertion_point(module_scope)
